@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2013 Oliver Heidelbach
+@c Copyright (C) 1993/2014 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -43,7 +43,7 @@ Channel Adapter (Infiniband)
 Computer Animation
 
 @item CA
-Computer Associates (manufacturer)
+Computer Associates (manufacturer), http://www.cai.com
 
 @item CAAD
 Computer Aided Architectural Design
@@ -76,10 +76,10 @@ Computer-Assisted Circuit Engineering and Allocating System
 Community Automated Counter-Terrorism Intelligence System (mil., USA)
 
 @item CAD
-Computer Aided  Dispatch / Drafting
+Computer Aided Design (CIM)
 
 @item CAD
-Computer Aided Design (CIM)
+Computer Aided Dispatch / Drafting
 
 @item CADE
 Computer Aided Document Engineering (Microstar)
@@ -115,7 +115,7 @@ Computer Analysis of Images and Patterns (Konferenz)
 Common APSE Interface Specification (APSE, API)
 
 @item CAIT
-Center for the Application of Information Technology (org., USA)
+Center for the Application of Information Technology (org., USA), http://www.cait.wustl.edu/cait
 
 @item CAIT
 Central Academy of Information Technology (org., MITI)
@@ -208,7 +208,7 @@ Consistency, Availability, Partition tolerance
 Computer Applications in Production and Engineering (conference, IFIP)
 
 @item CAPEC
-Common Attack Pattern Enumeration and Classification
+Common Attack Pattern Enumeration and Classification, http://capec.mitre.org/
 
 @item CAPI
 Communication Application Program Interface (ISDN, API)
@@ -253,7 +253,7 @@ Contents of the Address Register (IBM, ELISP, CDR)
 Computer Aided aRchiving and Change Accounting System
 
 @item CARD
-Candidate Access Router Discovery (RFC 4066)
+Candidate Access Router Discovery (RFC 4066), ftp://ftp.rfc-editor.org/in-notes/rfc4066.txt
 
 @item CARDS
 Central Archive for Reusable Defense Software (mil., USA)
@@ -316,7 +316,7 @@ Computer Aided Software Testing
 Central Alaska Time [-1000] (TZ)
 
 @item CAT
-Common Authentication Technology (IETF, RFC 1511)
+Common Authentication Technology (IETF, RFC 1511), ftp://ftp.rfc-editor.org/in-notes/rfc1511.txt
 
 @item CAT
 Computer Aided Technology (fair)
@@ -337,7 +337,7 @@ Computer Aided Telephone Interviewing
 Computer-Assisted Tactical Information System (mil., USA)
 
 @item CATNIP
-Common ArchiTecture for Next generation Internet Protocol (IPNG, RFC 1707)
+Common ArchiTecture for Next generation Internet Protocol (IPNG, RFC 1707), ftp://ftp.rfc-editor.org/in-notes/rfc1707.txt
 
 @item CATOSL
 Computer Associates - Trusted Open Source License (CA), "CA-TOSL"
@@ -346,7 +346,7 @@ Computer Associates - Trusted Open Source License (CA), "CA-TOSL"
 CodeWarrior Analysis Tools
 
 @item CAUCE
-Coalition Against Unsolicited Commercial Email (org., Internet, spam, UCE)
+Coalition Against Unsolicited Commercial Email (org., Internet, spam, UCE), http://www.cauce.org
 
 @item CAV
 Constant Angular Velocity (CD, HDD, MOD)
@@ -427,7 +427,7 @@ Canon Buffer Transmission (Fax)
 Computer-Based Training
 
 @item CBT
-Core Based Tree [multicast protocol] (IP, RFC 1949/2189, ST, Multicast)
+Core Based Tree [multicast protocol] (IP, RFC 1949/2189, ST, Multicast), ftp://ftp.rfc-editor.org/in-notes/rfc2189.txt, ftp://ftp.rfc-editor.org/in-notes/rfc1949.txt
 
 @item CBT
 Cursor Backward Tabulation (CFT)
@@ -472,7 +472,7 @@ Cablelabs Client Configuration (DHCP)
 Catalyst Control Center (ATI, Windows)
 
 @item CCC
-Chaos Computer Club (org.)
+Chaos Computer Club (org.), http://www.ccc.de
 
 @item CCC
 Computer Control Center
@@ -487,13 +487,13 @@ Campus Computer Communication Association (org., USA)
 Common Control CHannel (GSM, mobile-systems)
 
 @item CCCI
-Center for Cyber Communities Initiative (org., Japan)
+Center for Cyber Communities Initiative (org., Japan), http://www.ccci.or.jp
 
 @item CCD
 Charge Coupled Device
 
 @item CCDCOE
-Cooperative Cyber Defence Centre of Excellence (org., NATO)
+Cooperative Cyber Defence Centre of Excellence (org., NATO), http://ccdcoe.org/
 
 @item CCE
 [visual basic] Control Creation Edition (VB, ActiveX, MS)
@@ -502,7 +502,7 @@ Cooperative Cyber Defence Centre of Excellence (org., NATO)
 Connection Control Entity
 
 @item CCETT
-Centre Commun d'Etudes de Telediffusion et Telecommunications (org., France)
+Centre Commun d'Etudes de Telediffusion et Telecommunications (org., France), http://www.ccett.fr
 
 @item CCF
 Campus Computing Facilities (org.)
@@ -529,7 +529,7 @@ Cold Cathode Fluorescent Tube (LCD, Display)
 Cache Coherent Interconnect
 
 @item CCIA
-Computer & Communication Industry Association (org.)
+Computer & Communication Industry Association (org.), http://www.ccianet.org/
 
 @item CCIRN
 Coordinating Committee of International Networks (org.)
@@ -541,7 +541,7 @@ Common Channel Interoffice Signaling (AT&T)
 Comite Consultatif International Telegraphique et Telephonique (org., ITU, predecessor)
 
 @item CCL
-Cerberus Central Limited (manufacturer)
+Cerberus Central Limited (manufacturer), http://www.cdj.co.uk
 
 @item CCM
 Change and Configuration Management
@@ -550,7 +550,7 @@ Change and Configuration Management
 CORBA Component Model (CORBA)
 
 @item CCM
-Counter with CBC-MAC (cryptography, CBC, MAC, RFC 3610)
+Counter with CBC-MAC (cryptography, CBC, MAC, RFC 3610), ftp://ftp.rfc-editor.org/in-notes/rfc3610.txt
 
 @item CCMDB
 Change and Configuration Management DataBase (IBM, Tivoli)
@@ -568,7 +568,7 @@ Computer / Communications Network Center
 Cache-Coherent Non Uniform Memory Access (SMP, NUMA), "cc-NUMA"
 
 @item CCP
-[PPP] Compression Control Protocol (PPP, RFC 1962)
+[PPP] Compression Control Protocol (PPP, RFC 1962), ftp://ftp.rfc-editor.org/in-notes/rfc1962.txt
 
 @item CCP
 Command Console Processor (CP/M)
@@ -598,7 +598,7 @@ Center for Computer Research in Music and Acoustics (org., Stanford, UK)
 [Conference on] Computer and Communications Security
 
 @item CCS
-Cambridge Cybernetic Society (org.)
+Cambridge Cybernetic Society (org.), http://www.pangaro.com/ccs
 
 @item CCS
 Cluster Configuration System (GFS)
@@ -622,7 +622,7 @@ Communications-Computer Systems, "C-CS"
 Computerized Charging System
 
 @item CCS
-Cyprus Computer Society (Org, Zypern)
+Cyprus Computer Society (Org, Zypern), http://www.cyprus2000.com/ccs
 
 @item CCS7
 Common Channel signaling System 7 (IN, DTAG, CCITT)
@@ -691,10 +691,10 @@ Computerized Digital Branch eXchange (PBX)
 Connected Device Configuration (JVM)
 
 @item CDC
-Control Data Corporation (manufacturer)
+Control Data Corporation (manufacturer), http://www.cdc.com
 
 @item CDC
-Cult of the Dead Cow (org.), "cDc"
+Cult of the Dead Cow (org.), "cDc", http://www.cultdeadcow.com
 
 @item CDD
 Component Design Document
@@ -706,7 +706,7 @@ Compact Disk - Digital Audio (CD, Digital audio), "CD-DA"
 Copper Distributed Data Interface (FDDI, UTP)
 
 @item CDE
-Certified Directory Engineer (Novell, Netware)
+Certified Directory Engineer (Novell, Netware), http://www.novell.com/education/cde/
 
 @item CDE
 Common Desktop Environment (Unix)
@@ -832,7 +832,7 @@ Context Dependent Symbolic Links (CDPN, NFS, GFS)
 Creative Decision Stimulation Systems (AI, DSS)
 
 @item CDT
-Cambridge Display Technology (manufacturer)
+Cambridge Display Technology (manufacturer), http://www.cdtltd.co.uk
 
 @item CDT
 Cell Delay Tolerance (ATN)
@@ -868,10 +868,10 @@ Compact Edition (MS, Windows)
 Connection Endpoint (UNI)
 
 @item CEARCH
-Cisco Educational ARCHive (Cisco, WWW)
+Cisco Educational ARCHive (Cisco, WWW), http://sunsite.unc.edu/cisco/cisco-home.html
 
 @item CEBIT
-welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"
+welt CEntrum Buero Information Telekommunikation (fair), "CeBIT", http://www.messe.de
 
 @item CEC
 Consumer Electronics Control [protocol]
@@ -925,7 +925,7 @@ Contract Equipment Manufacturer
 CICS Enhanced Master Terminal transaction (CICS, IBM)
 
 @item CEN
-Comite Europeen de Normalisation (org., Europe, Brussels)
+Comite Europeen de Normalisation (org., Europe, Brussels), http://www.cenorm.be
 
 @item CENELEC
 Comite Europeen de Normalisation ELECtrotechnique (org., CEN, Europe)
@@ -937,7 +937,7 @@ Council of European National Top level Domain Registries (org., TLD)
 CMOS-Ein-Platinen-Allzweck-Computer (IC, CMOS, C'T)
 
 @item CEPIS
-Council of European Professional Informatics Societies (org., Europe)
+Council of European Professional Informatics Societies (org., Europe), http://www.cepis.org
 
 @item CEPT
 Conference of European Postal and Telecommunications administrations (org., CCITT, conference, Europe)
@@ -949,10 +949,10 @@ Cell Error Ratio (ATM)
 California Educational and Research Federation NETwork (network), "CERFNet"
 
 @item CERN
-Conseil Europeenne pour la Recherche Nucleaire (org., Europe, Geneva)
+Conseil Europeenne pour la Recherche Nucleaire (org., Europe, Geneva), http://www.cern.ch
 
 @item CERT
-Computer Emergency Response Team (DARPA, CMU, Internet)
+Computer Emergency Response Team (DARPA, CMU, Internet), http://www.cert.org
 
 @item CES
 C-bit Errored Seconds (DS3/E3, BIT)
@@ -967,16 +967,16 @@ Circuit Emulation Service
 Consumer Electronics Show (fair, USA)
 
 @item CESAR
-Central Employment Search And Retrieval (WWW)
+Central Employment Search And Retrieval (WWW), http://www.cesar.de
 
 @item CESG
-Communications-Electronics Security Group (org., UK, GCHQ)
+Communications-Electronics Security Group (org., UK, GCHQ), http://www.cesg.gov.uk
 
 @item CET
 Central European Time [+0100] (TZ, MET)
 
 @item CET
-Centro de Estudes de Telecomunicoes (org., Portugal)
+Centro de Estudes de Telecomunicoes (org., Portugal), http://www.cet.pt
 
 @item CF
 Carry Flag (assembler)
@@ -1012,7 +1012,7 @@ Center for Engineering (org., JIEO, DISA)
 Compact Font Format (Adobe)
 
 @item CFI
-CAD Framework Initiative (org., CAD)
+CAD Framework Initiative (org., CAD), http://www.cfi.org
 
 @item CFM
 Clock From Master (CTM, Rambus)
@@ -1042,7 +1042,7 @@ Contention Free Period (PCF, MAC)
 Complete Fair Queueing (Linux)
 
 @item CFS
-Center for Standards (org., JIEO, DISA)
+Center for Standards (org., JIEO, DISA), http://www.itsi.disa.mil
 
 @item CFS
 Cryptographic FileSystem (Linux, cryptography)
@@ -1057,7 +1057,7 @@ Cusor Forward Tabulation (CBT)
 Call For Vote (Internet, Usenet), "CfV"
 
 @item CFWS
-Comments / Folding White Space (RFC 1822)
+Comments / Folding White Space (RFC 1822), ftp://ftp.rfc-editor.org/in-notes/rfc1822.txt
 
 @item CG
 C for Graphics (Nvidia, MS), "Cg"
@@ -1123,7 +1123,7 @@ Computer Graphic Virtual Device Interface, "CG-VDI"
 CHisquard Automatic Interaction Detector / Detection (SPSS)
 
 @item CHAP
-[PPP] Challenge Handshake Authentication Protocol (PPP, RFC 1334/1994)
+[PPP] Challenge Handshake Authentication Protocol (PPP, RFC 1334/1994), ftp://ftp.rfc-editor.org/in-notes/rfc1994.txt, ftp://ftp.rfc-editor.org/in-notes/rfc1334.txt
 
 @item CHCP
 CHange Code Page (DOS)
@@ -1135,7 +1135,7 @@ Computer Hardware Description Language (HDL)
 Cryptographic Hardware and Embedded Systems [conference]
 
 @item CHEST
-Computers in Higher Education Software Team (org., UK)
+Computers in Higher Education Software Team (org., UK), http://www.niss.ac.uk/chest
 
 @item CHILL
 CCITT HIgh Level programming Language (CCITT)
@@ -1171,10 +1171,10 @@ Configuration Item (CM)
 Congestion Indicator
 
 @item CIA
-CAN In Automation (org., CAN), "CiA"
+CAN In Automation (org., CAN), "CiA", http://www.can-cia.de
 
 @item CIAC
-Computer Incident Advisory Capability (org., LLNL, Internet)
+Computer Incident Advisory Capability (org., LLNL, Internet), http://ciac.llnl.gov
 
 @item CIB
 Collective Intelligent Brick (IBM, HDD)
@@ -1213,13 +1213,13 @@ Configuration - Installation - Distribution (IBM)
 Common Intrusion Detection Framework (CIDF, IDS)
 
 @item CIDR
-Classless Internet Domain Routing [protocol] (RFC 1519)
+Classless Internet Domain Routing [protocol] (RFC 1519), ftp://ftp.rfc-editor.org/in-notes/rfc1519.txt
 
 @item CIDS
 Cabin Intercommunication Data System (Airbus, A380, TCP/IP)
 
 @item CIE
-Commission Internationale de l'Eclairage (org.)
+Commission Internationale de l'Eclairage (org.), http://www.hike.te.chiba-u.ac.jp/ikeda/CIE/home.html
 
 @item CIF
 Common Intermediate Format [352x288] (video)
@@ -1228,7 +1228,7 @@ Common Intermediate Format [352x288] (video)
 Common Internet File System (TCP/IP)
 
 @item CIIRC
-China Internet Illegal Information Reporting Center (China, org.)
+China Internet Illegal Information Reporting Center (China, org.), http://ciirc.china.cn
 
 @item CIL
 Common Intermediation Language (CLI)
@@ -1255,7 +1255,7 @@ CIM Object Model (CIM, WBEM)
 CIncinnati Milacron Operating System (OS), "CiMOS"
 
 @item CIO
-Cisco Information Online (Cisco, WWW)
+Cisco Information Online (Cisco, WWW), http://www.cisco.com
 
 @item CIP
 Carrier Identification Parameter
@@ -1276,7 +1276,7 @@ Computer Integrated Processing
 Computer-Investitions-Programm
 
 @item CIPA
-Camera & Imaging Products Association (org.)
+Camera & Imaging Products Association (org.), http://www.cipa.jp/english/
 
 @item CIPA
 Children's Internet Protection Act (Internet, USA, COPA)
@@ -1294,7 +1294,7 @@ Committed Information Rate (ATM)
 Cross Interleaved Reed-solomon Code (CD)
 
 @item CIRCIT
-Centre for International Research on Communication and Information Technology (org., Australia)
+Centre for International Research on Communication and Information Technology (org., Australia), http://teloz.latrobe.edu.au/circit
 
 @item CIS
 Card Information Structure / Space (PCMCIA)
@@ -1303,7 +1303,7 @@ Card Information Structure / Space (PCMCIA)
 Command Information System (mil., USA)
 
 @item CIS
-Compuserve Information Systems (network)
+Compuserve Information Systems (network), http://www.compuserve.com
 
 @item CIS
 Contact Image Sensor
@@ -1330,7 +1330,7 @@ Certified Information Security Officer (ISTA)
 Comite International Special des Perturbations Radioelectriques (org.)
 
 @item CISRAM
-Cybernetics & Intelligent Systems - Robotics, Automation & Mechatronics (IEEE, conference), "CIS-RAM"
+Cybernetics & Intelligent Systems - Robotics, Automation & Mechatronics (IEEE, conference), "CIS-RAM", http://www.cis-ram.org
 
 @item CISRT
 Chinese Internet Security Response Team (org., China)
@@ -1366,7 +1366,7 @@ Customer-Initiated Upgrade [switch] ??? (IBM)
 Cyclone Integrated Video Interfaces Controller (Apple)
 
 @item CIX
-Commercial Internet eXchange (ISP)
+Commercial Internet eXchange (ISP), http://www.cix.org
 
 @item CJK
 Chinese - Japanese - Korean [encoding]
@@ -1483,7 +1483,7 @@ CLasS IDentifier (COM)
 ConnectionLess Transport Protocol (OSI)
 
 @item CLUG
-Chemnitzer Linux User Group (Chemnitz, user group, Linux)
+Chemnitzer Linux User Group (Chemnitz, user group, Linux), http://www.clug.in-chemnitz.de
 
 @item CLUT
 Color LookUp Table (VGA)
@@ -1522,7 +1522,7 @@ Common Messaging Calls [interface] (XAPIA)
 Complement Carry Flag (assembler)
 
 @item CMC
-Computer Mediated Communications [studies centre] (org., USA)
+Computer Mediated Communications [studies centre] (org., USA), http://www.rpi.ede/~decemi/cmc/center.html
 
 @item CMDS
 Cambridge Model Distributed System (OS)
@@ -1579,7 +1579,7 @@ CMIP Over LLC (OSI, LLC)
 Complementary-symmetry Metal-Oxide Semiconductor (IC)
 
 @item CMOT
-CMIP Over TCP (OSI, RFC 1189, CMIP, TCP)
+CMIP Over TCP (OSI, RFC 1189, CMIP, TCP), ftp://ftp.rfc-editor.org/in-notes/rfc1189.txt
 
 @item CMP
 Chip MultiProcessing (IBM, HP, Sun)
@@ -1609,7 +1609,7 @@ Color Management System
 Content Management Software / System
 
 @item CMS
-Cryptographic Message Syntax (cryptography, RFC 2630)
+Cryptographic Message Syntax (cryptography, RFC 2630), ftp://ftp.rfc-editor.org/in-notes/rfc2630.txt
 
 @item CMSS
 ???
@@ -1621,7 +1621,7 @@ Connection ManagemenT (FDDI)
 Cable MODEM Termination System (DOCSIS, MODEM)
 
 @item CMU
-Carnegie-Mellon-University (org.)
+Carnegie-Mellon-University (org.), http://www.cs.cmu.edu, http://www.cmu.edu
 
 @item CMX
 Communications Manager uniX (Unix)
@@ -1648,7 +1648,7 @@ Copy Network
 Corporate Network
 
 @item CNA
-Certified Novell Administrator (Novell, Netware)
+Certified Novell Administrator (Novell, Netware), http://www.novell.com/education/cna/
 
 @item CNA
 Communication Network Architecture (SEL)
@@ -1660,7 +1660,7 @@ Communications Network Application
 CVE Numbering Authorities (CVE)
 
 @item CNBC
-Center for Neural Basis of Cognition (org., CMU, AI)
+Center for Neural Basis of Cognition (org., CMU, AI), http://www.cs.cmu.edu:8001/afs/cs/project/cnbc/cnbc.html
 
 @item CNC
 Communications Network Control
@@ -1675,7 +1675,7 @@ Caldera Network Desktop (Linux)
 Caller Number Delivery (MODEM)
 
 @item CNE
-Certified Netware Engineer (Novell, Netware)
+Certified Netware Engineer (Novell, Netware), http://www.novell.com/education/cne/
 
 @item CNE
 Corporate Network Edition (eBlaster)
@@ -1684,13 +1684,13 @@ Corporate Network Edition (eBlaster)
 Certified Netware Engineers Professional Association (org., Netware)
 
 @item CNET
-Centre Nationale d'Etudes des Telecommunications (org., France)
+Centre Nationale d'Etudes des Telecommunications (org., France), http://www.cnet.fr
 
 @item CNI
-Certified Netware Instructor (Novell, Netware)
+Certified Netware Instructor (Novell, Netware), http://www.novell.com/education/cni/
 
 @item CNI
-Coalition for Networked Information (org.)
+Coalition for Networked Information (org.), http://www.cni.org
 
 @item CNI
 Common Network Interface
@@ -1699,7 +1699,7 @@ Common Network Interface
 Coalition for Networked Information DIRectories (Internet)
 
 @item CNIL
-Commission Nationale de l'Informatique et des Libertes (org., France)
+Commission Nationale de l'Informatique et des Libertes (org., France), http://www.cnil.fr
 
 @item CNM
 Communications Network Management
@@ -1714,7 +1714,7 @@ Communications Network for Manufacturing Applications
 Cylink Network Management System
 
 @item CNNIC
-China interNet Network Information Center (org., Internet, China)
+China interNet Network Information Center (org., Internet, China), http://www.cnnic.net.cn
 
 @item CNP
 Corporate Network Products (TPS)
@@ -1729,7 +1729,7 @@ Communications and Network Riser
 Compressed News ReCeive Via UUCP
 
 @item CNS
-Certified Novell Salesperson (Novell, Netware)
+Certified Novell Salesperson (Novell, Netware), http://www.novell.com/education/powersell/
 
 @item CNS
 Complimentary Network Service
@@ -1759,13 +1759,13 @@ Caldera Open Administration System (Linux)
 Cache On A STick (Intel)
 
 @item COAST
-Computer Operations, Audit and Security Technology (org.)
+Computer Operations, Audit and Security Technology (org.), http://www.cs.purdue.edu/coast/coast.html
 
 @item COBOL
 COmmon Business Orientated Language
 
 @item COBRA
-COmmunication technology: Basic Research and Applications (org., Netherlands)
+COmmunication technology: Basic Research and Applications (org., Netherlands), http://www.cobra.tue.nl
 
 @item COBRA
 COmmunication technology: Basic Research and Applications
@@ -1834,7 +1834,7 @@ Computer Output on LaserDisk
 COprozessor fuer LISP auf der Basis von RISC (RISC)
 
 @item COLLADA
-COLLAborative Design Activity (XML, 3D)
+COLLAborative Design Activity (XML, 3D), http://collada.org/
 
 @item COM
 Component Object Model (OLE, OLE2, OCX, ActiveX, MS)
@@ -1861,7 +1861,7 @@ COnversational Multimodal Interaction with Computers [project] (Europe)
 COMputergestuetztes PARtner-TeilebestandsSystem (MBAG)
 
 @item COMPTIA
-COMPuting Technology Industry Association (org.)
+COMPuting Technology Industry Association (org.), http://www.comptia.de
 
 @item COMTECH
 COMputer TECHnologies (fair)
@@ -1897,22 +1897,22 @@ Child Online Protection Act (Internet, USA, CIPA)
 Certified Output Protection Protocol (MS, RSA, WPE)
 
 @item COPS
-Common Open Policy Service protocol (RFC 2748)
+Common Open Policy Service protocol (RFC 2748), ftp://ftp.rfc-editor.org/in-notes/rfc2748.txt
 
 @item COPS
 Computer Oracle and Password System (Unix)
 
 @item COPSPR
-Common Open Policy Service for Policy Provisioning (COPS, RFC 3084), "COPS-PR"
+Common Open Policy Service for Policy Provisioning (COPS, RFC 3084), "COPS-PR", ftp://ftp.rfc-editor.org/in-notes/rfc3084.txt
 
 @item CORAN
 Communication ORiented Application aNalysis
 
 @item CORBA
-Common Object Request Broker Architecture (OMG)
+Common Object Request Broker Architecture (OMG), http://www.omg.org/news/witepprz.htm, http://www.acl.lanl.gov/CORBA
 
 @item CORDIS
-COmmunity Research and Development Information Service (Europe)
+COmmunity Research and Development Information Service (Europe), http://www.cordis.lu
 
 @item COS
 Card Operating System (OS, ICC)
@@ -2002,7 +2002,7 @@ Collaboration Partner Agreement (CPPA, ebXML)
 Collaboration Protocol Agreements (ebXML)
 
 @item CPAN
-Comprehensive PERL Archive Network (PERL)
+Comprehensive PERL Archive Network (PERL), http://www.cpan.org
 
 @item CPC
 Central Processing Complex
@@ -2200,7 +2200,7 @@ Common Routing Connection Group
 Color Rendering Dictionary (PS)
 
 @item CREN
-Corporation for Research and Educational Networking (network)
+Corporation for Research and Educational Networking (network), http://www.cren.net
 
 @item CRET
 Color - Resolution Enhancement Technology (HP), "C-REt"
@@ -2212,7 +2212,7 @@ Connection Related Function Virtual Channel (UPC, UNI), "CRF(VC)"
 Connection Related Function Virtual Path (UPC, UNI), "CRF(VP)"
 
 @item CRI
-Cray Research, Inc. (manufacturer)
+Cray Research, Inc. (manufacturer), http://www.cray.com
 
 @item CRIMM
 Continuity Rambus Inline Memory Module (RIMM, IC, Rambus)
@@ -2227,7 +2227,7 @@ Complex-Reduced Instruction Set Computer
 Complex-Reduced Instruction Set Processor
 
 @item CRISP
-Cross Registry Internet Service Protocol (Internet, RFC 3707)
+Cross Registry Internet Service Protocol (Internet, RFC 3707), ftp://ftp.rfc-editor.org/in-notes/rfc3707.txt
 
 @item CRJE
 Conversational Remote Job Entry (RJE)
@@ -2266,7 +2266,7 @@ CMOS Reload Switch (CMOS, Gigabyte), "C.R.S."
 Cathode Ray Tube
 
 @item CRT
-Computer Technology Research [corporation] (provider)
+Computer Technology Research [corporation] (provider), http://www.ctrcorp.com
 
 @item CRTC
 Cathode Ray Tube Controller (EGA, VGA, MCGA)
@@ -2329,7 +2329,7 @@ Concurrent SuperComputing Consortium (org.)
 Caldera Systems Curriculum Developers (Caldera)
 
 @item CSCSI
-Canadian Society for the Computational Studies of Intelligence (org., Canada, AI)
+Canadian Society for the Computational Studies of Intelligence (org., Canada, AI), http://ai.iit.nrc.ca/cscsi_point.org
 
 @item CSCW
 Computer Supported Cooperative Work
@@ -2362,7 +2362,7 @@ Client-Server Environment
 Cable SELect (EIDE, HD)
 
 @item CSELT
-Centro Studi E Laboratori Telecomunicazioni [s.p.a.] (org., Italy)
+Centro Studi E Laboratori Telecomunicazioni [s.p.a.] (org., Italy), http://www.cselt.it
 
 @item CSEM
 Centre Suisse d'Electronique et de Microtecnique (org., Switzerland)
@@ -2389,7 +2389,7 @@ Common Secure Interoperability (CORBA)
 Common System Interface (Intel, Xeon)
 
 @item CSI
-CompuServe Incorporated (ISP)
+CompuServe Incorporated (ISP), http://www.compuserve.com
 
 @item CSI
 Convergence Sublayer Indication (ATM)
@@ -2419,7 +2419,7 @@ Commonwealth Scientific and Industrial Research Organization (org., UK)
 Central Schengen Information Systen (SIS, Europe, Strasbourg)
 
 @item CSKI
-Ceska Spolecnost pro Kybernetiku a Informatiku (org., Tschechien)
+Ceska Spolecnost pro Kybernetiku a Informatiku (org., Tschechien), http://www.ecdl.cz
 
 @item CSL
 Callable Services Library (IBM, VM/ESA, CMS)
@@ -2461,7 +2461,7 @@ Card Select Number (PNP)
 Computer + Science NETwork (USA, network, BITNET)
 
 @item CSP
-Centro Supercacolo Piemonte (org., Italy, HPC)
+Centro Supercacolo Piemonte (org., Italy, HPC), http://services.csp.it/welcome.html
 
 @item CSP
 Chip Scale Package (IC)
@@ -2485,7 +2485,7 @@ Convergence Sublayer Protocol Data Unit (ATM, PDU), "CS PDU"
 Certified Scrum Product Owner (Scrum)
 
 @item CSPP
-Computer Systems Policy Project [group] (org., USA. manufacturer)
+Computer Systems Policy Project [group] (org., USA. manufacturer), http://www.cspp.org
 
 @item CSR
 Cell misSequenced Ratio (ATM)
@@ -2509,7 +2509,7 @@ Cross Site Request Forgery (WWW, Internet)
 Computer Systems Research Group (org., Unix, BSD)
 
 @item CSS
-Cascading Style Sheets (HTML, XML, WWW,  JavaScript)
+Cascading Style Sheets (HTML, XML, WWW, JavaScript)
 
 @item CSS
 Computer Sub System
@@ -2533,10 +2533,10 @@ Computer Supported Telecommunications Applications (ECMA, CTI)
 Computer Science and Technology Board (org., NRC)
 
 @item CSTC
-Computer Security Technology Center (org., CIAC)
+Computer Security Technology Center (org., CIAC), http://ciac.llnl.gov/cstc/cstchome.html
 
 @item CSTO
-Computing Systems Technology Office (org., ARPA)
+Computing Systems Technology Office (org., ARPA), http://www.arpa.mil/csto/welcome.html
 
 @item CSTR
 Centre for Speech Technology Research
@@ -2557,19 +2557,19 @@ Client SMTP Validation (SMTP, SPAM)
 Comma Separated Values
 
 @item CT
-[magazin fuer] Computer Technik, "c't" 
+[magazin fuer] Computer Technik, "c't" , http://www.heise.de/
 
 @item CT
 Chipcard Terminal (ICC, CT)
 
 @item CT
-Chips & Technologies (manufacturer), "C&T"
+Chips & Technologies (manufacturer), "C&T", http://www.chips.com
 
 @item CT
 Clackamas Technology (Intel, Pentium, CPU)
 
 @item CTAN
-Comprehensive Tex Archive Network (TeX, FTP)
+Comprehensive Tex Archive Network (TeX, FTP), http://www.ctan.org
 
 @item CTAPI
 Chipcard Terminal Application Program Interface (ICC, CT, API), "CT-API"
@@ -2599,7 +2599,7 @@ Cygwin Technical Documentation Writer (Cygwin)
 Compliance Test and Evaluation, "CT & E"
 
 @item CTEA
-Copyright Term Extension Act (USA,  DRM)
+Copyright Term Extension Act (USA, DRM)
 
 @item CTEC
 Certified Technical Education Center (MS)
@@ -2629,7 +2629,7 @@ Community Technology Preview
 Cordless Telephony Profile (Bluetooth)
 
 @item CTR
-[columbia university] Center for Telecommunications Research (org., USA)
+[columbia university] Center for Telecommunications Research (org., USA), http://www.ctr.columbia,edu
 
 @item CTR
 Common Technical Regulations (Europe)
@@ -2683,13 +2683,13 @@ Console teleTYpe
 Call Up (Unix)
 
 @item CU
-[L]       [see you [Later]] (slang, Usenet, IRC)
+see you (slang, Usenet, IRC)
 
 @item CUA
 Common User Application
 
 @item CUCUG
-Champaign-Urbana Computer Users Group (org., user group)
+Champaign-Urbana Computer Users Group (org., user group), http://www.cucug.org
 
 @item CUD
 Color Universal Design (Eizo, LCD)
@@ -2704,7 +2704,10 @@ Character User Interface (UI)
 Common User Interface (AMS, UI)
 
 @item CUL
-Computer Und Lernen (org.)
+Computer Und Lernen (org.), http://www.computerundlernen.de
+
+@item CUL
+see you Later (slang, Usenet, IRC)
 
 @item CUP
 Competitive UPgrade (MS)
@@ -2728,7 +2731,7 @@ ComputerUnterstuetzte Unterweisung
 Chemical Vapor Deposition
 
 @item CVE
-Common Vulnerabilities and Exposures
+Common Vulnerabilities and Exposures, http://cve.mitre.org
 
 @item CVF
 Compressed Volume File (DOS)
@@ -2736,11 +2739,14 @@ Compressed Volume File (DOS)
 @item CVIA
 Computer Virus Industry Association (org., USA)
 
+@item CVN
+CounterVandalism Network (Wikia, VSTF)
+
 @item CVS
 Computer Vision Syndrome
 
 @item CVS
-Concurrent Versions System (Unix)
+Concurrent Versions System (Unix), http://www.cvshome.org
 
 @item CVSD
 Continuous Variable Delta Modulation (telecommunication)
@@ -2749,16 +2755,16 @@ Continuous Variable Delta Modulation (telecommunication)
 Codex Vector Sum Excited Linear Prediction [algorithm] (Motorola, VOFR)
 
 @item CVSS
-Common Vulnerability Scoring System (NIAC)
+Common Vulnerability Scoring System (NIAC), http://www.first.org/cvss/
 
 @item CVW
 MITRE Collaborative Virtual Workspace license
 
 @item CWE
-Common Weakness Enumeration
+Common Weakness Enumeration, http://cwe.mitre.org/
 
 @item CWI
-Centrum voor Wiskunde en Informatica (org., Netherlands)
+Centrum voor Wiskunde en Informatica (org., Netherlands), http://www.cwi.nl
 
 @item CWIS
 Campus Wide Information System
@@ -2779,13 +2785,13 @@ Clustered eXtended File System (SGI, RAID, XFS)
 Common X-windows Interface (Unix)
 
 @item CXML
-Commerce eXtensible Markup Language (XML), "cXML"
+Commerce eXtensible Markup Language (XML), "cXML", http://www.cxml.org
 
 @item CXTP
-ConteXt Transfer Protocol (RFC 4067)
+ConteXt Transfer Protocol (RFC 4067), ftp://ftp.rfc-editor.org/in-notes/rfc4067.txt
 
 @item CYBOX
-CYBer Observable eXpression, "CybOX"
+CYBer Observable eXpression, "CybOX", http://cybox.mitre.org/
 
 @item CYMK
 Cyan, Yellow, Magenta, blacK (color system)
