@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2013 Oliver Heidelbach
+@c Copyright (C) 1993/2014 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -61,7 +61,7 @@ Fully Automatic Installation
 Flash Authority Identification Data (EEPROM)
 
 @item FAIS
-Finnish Artificial Intelligence Society (org., Finland, AI)
+Finnish Artificial Intelligence Society (org., Finland, AI), http://www.uwasa.fi/stes/eindex.html
 
 @item FAL
 File Access Listener (DEC, DNA)
@@ -76,7 +76,7 @@ Floating gate Avalanche injection Metal Oxide Semiconductor (IC)
 Fast Amsterdam MultiProcessor
 
 @item FANP
-Flow Attribute Notification Protocol (Toshiba, RFC 2129)
+Flow Attribute Notification Protocol (Toshiba, RFC 2129), ftp://ftp.rfc-editor.org/in-notes/rfc2129.txt
 
 @item FAP
 Flight Attendant Panel (Airbus, A380, CIDS, LCD)
@@ -115,7 +115,7 @@ Fast ARM Solutions Toolkit (ARM, Palm, PDA)
 First Application System Test
 
 @item FAST
-Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.)
+Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.), http:/www.fast.de
 
 @item FAT
 File Allocation Table (DOS)
@@ -127,10 +127,10 @@ Fibre-Attached Technology Adapted (HP, SATA, HDD)
 Flow Admission Update [message] (LFAP)
 
 @item FAU
-Friedrich-Alexander-Universitaet (org., Erlangen, Germany, Nuernberg, Germany)
+Friedrich-Alexander-Universitaet (org., Erlangen, Germany, Nuernberg, Germany), http://www.uni-erlangen.de
 
 @item FAW
-Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm)
+Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm), http://merlin.faw.uni-ulm.de/faw
 
 @item FAXP
 FAX Profile (Bluetooth, SPP), "FaxP"
@@ -187,7 +187,7 @@ File Control BlockS (DOS)
 Fast Communication Controller (SCC, MCC)
 
 @item FCC
-Federal Communications Commission (org., USA)
+Federal Communications Commission (org., USA), http://www.fcc.gov
 
 @item FCC
 Forward Carbon Copy (telecommunication)
@@ -196,7 +196,7 @@ Forward Carbon Copy (telecommunication)
 Frequency Correction CHannel (GSM, mobile-systems)
 
 @item FCCN
-Fundacao para a Computacao Cientifica Nacional (org., Portugal)
+Fundacao para a Computacao Cientifica Nacional (org., Portugal), http://www.fccn.pt
 
 @item FCD
 Floating Car Data
@@ -226,7 +226,7 @@ Flow Control Indicator (DLSW)
 Forward Cache Identifier (CATNIP)
 
 @item FCIA
-Fibre Channel Industry Association (org.)
+Fibre Channel Industry Association (org.), http://fibrechannel.org/
 
 @item FCIP
 Fibre Channel over Internet Protocol (SAN, FC, IP)
@@ -331,7 +331,7 @@ Flat Display Mounting Interface (VESA, MIS)
 Functional Device Object
 
 @item FDSN
-Federation of Digital Seismograph Networks (org.)
+Federation of Digital Seismograph Networks (org.), http://www.fdsn.org/
 
 @item FDT
 Formal Description Technique
@@ -369,6 +369,9 @@ Forward Error Correction (GSM, mobile-systems)
 @item FECN
 Forward Explicit Congestion Notification (ATM)
 
+@item FEDRAMP
+FEDeral Risk and Authorization Management Program (USA), "FedRAMP"
+
 @item FEFCO
 ???
 
@@ -385,7 +388,7 @@ Finite Elemente Methode
 Free-net Erlangen/Nuernberg
 
 @item FEP
-Firewall Enhancement Protocol (RFC 3093)
+Firewall Enhancement Protocol (RFC 3093), ftp://ftp.rfc-editor.org/in-notes/rfc3093.txt
 
 @item FEP
 Flight Envelope Protection (Airbus, A380)
@@ -400,7 +403,7 @@ Forward Error Correction (satellite)
 Far End Receive Failure (UNI, ATM, SONET, OAM)
 
 @item FESI
-Federacion Espanola de Sociedades de Informatica (org., Spain)
+Federacion Espanola de Sociedades de Informatica (org., Spain), http://www.fesi.fi.upm.es/
 
 @item FET
 Field Effect Transistor
@@ -469,7 +472,7 @@ File system Hierarchy Standard (Linux, LSB)
 Frequency Hopping Spread Spectrum (WLAN)
 
 @item FIA
-Fiberoptic Industry Association (org.)
+Fiberoptic Industry Association (org.), http://www.netwales.co.uk/fia/welcome.htm
 
 @item FIB
 Forwarding Information Base (router, LAN, Internet)
@@ -478,7 +481,7 @@ Forwarding Information Base (router, LAN, Internet)
 FInanzBUchhaltung
 
 @item FIC
-First International Computer [inc.] (manufacturer)
+First International Computer [inc.] (manufacturer), http://www.fic.com.tw
 
 @item FICS
 Free Internet Chess Server
@@ -489,6 +492,9 @@ File IDentifier (APDU)
 @item FID
 File Identifier Descriptor (UDF, CD-R)
 
+@item FIDO
+Fast IDentity Online (org.), http://fidoalliance.org/
+
 @item FIDO
 FIlter Device Object, "FiDO"
 
@@ -508,7 +514,7 @@ Forth Interest Group (org., Forth)
 Frank, Ian and Glenn's LETters (ASCII, fonts)
 
 @item FILE
-Free Internet Lexicon and Encyclopedia (WWW, DICT)
+Free Internet Lexicon and Encyclopedia (WWW, DICT), http://www.dict.org/file.html
 
 @item FILO
 First In Last Out
@@ -562,10 +568,10 @@ Federal Internet Requirements Panel (Internet, USA)
 Federated Internet Registry Service (LDAP, Internet)
 
 @item FIRST
-ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik (org., GMD, Berlin, Germany)
+ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik (org., GMD, Berlin, Germany), http://www.gmd.de/first/firsthome.html
 
 @item FIRST
-Forum of Incident Response and SecuriTy (org., NIST)
+Forum of Incident Response and SecuriTy (org., NIST), http://first.org
 
 @item FIS
 FachInformationsSystem
@@ -576,6 +582,9 @@ FuehrungsInformationsSysteme
 @item FISH
 FIle transfer with a SHell, "FiSH"
 
+@item FISMA
+Federal Information Security Management Act (USA)
+
 @item FIT
 Failures In Time
 
@@ -586,13 +595,13 @@ Fraunhofer institut fuer angewandte InformationsTechnik (org.)
 Functional Interpolating Transformation System
 
 @item FITUG
-Foerderverein Informationstechnik und Gesellschaft [e.V.] (org.)
+Foerderverein Informationstechnik und Gesellschaft [e.V.] (org.), http://www.fitug.de
 
 @item FIU
 Fingerprint Identification Unit (Sony)
 
 @item FIZ
-FachInformationsZentrum karlsruhe Org., Germany
+FachInformationsZentrum karlsruhe Org., Germany, http://www.fiz-karlsruhe.de
 
 @item FK
 Foundation Kit (NextStep, OpenStep, Apple, Rhapsody)
@@ -679,10 +688,10 @@ FachNormenausschuss Informationsverarbeitung [1962-1987] (DIN, NI, predecessor)
 Fiber Optic
 
 @item FOA
-Fiber Optic Association (org.)
+Fiber Optic Association (org.), http://www.std.com/fotec/foa.htm
 
 @item FOAF
-Friend Of A Friend [vocabulary] (RDF)
+Friend Of A Friend [vocabulary] (RDF), http://www.foaf-project.org/
 
 @item FOC
 Fiber Optic Cable / Communications
@@ -700,16 +709,16 @@ Formal specification of ODA document structures (ODA, ISO)
 [international conference on] Foundations Of Data Organization and algorithms (conference, INRIA)
 
 @item FOEBUD
-[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBuD"
+[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBuD", http://www.foebud.org
 
 @item FOIRL
 Fiber Optic InterRepeater Link (OWG)
 
 @item FOKUS
-Forschungszentrum fuer Offene KommUnikationsSysteme (org., GMD, Berlin, Germany)
+Forschungszentrum fuer Offene KommUnikationsSysteme (org., GMD, Berlin, Germany), http://www.fokus.gmd.de
 
 @item FOLDOC
-Free OnLine Dictionary Of Computing (WWW, UK)
+Free OnLine Dictionary Of Computing (WWW, UK), http://wombat.doc.ic.ac.uk
 
 @item FOLED
 Flexible Organic Light Emitting Display (OLED)
@@ -727,7 +736,7 @@ Fiber Optics Network
 Friends Of O'reilly [meeting]
 
 @item FOOBAR
-FTP Operation Over Big Address Records (RFC 1639, FTP)
+FTP Operation Over Big Address Records (RFC 1639, FTP), ftp://ftp.rfc-editor.org/in-notes/rfc1639.txt
 
 @item FOOT
 Forum for Object Oriented Technology (CERN, OOP)
@@ -736,7 +745,7 @@ Forum for Object Oriented Technology (CERN, OOP)
 Feature Orientated Programming
 
 @item FOP
-Formatting Object Processor (Apache, XSL-FO)
+Formatting Object Processor (Apache, XSL-FO), http://xml.apache.org/fop/
 
 @item FORMEX
 FORMalised EXchange of electronic publications (SGML, Europe)
@@ -748,10 +757,10 @@ Formal Object Role Modelling Language
 FORmula TRANslation
 
 @item FORTWIHR
-FORschungsverbund fuer Technisch-WIssenschaftliches HochleistungsRechnen (org., Bavaria)
+FORschungsverbund fuer Technisch-WIssenschaftliches HochleistungsRechnen (org., Bavaria), http://www5.informatik.tu-muenchen.de/forschung/fortwihr
 
 @item FORWISS
-bayerisches FORschungszentrum fuer WISsensbasierte Systeme (org., KI)
+bayerisches FORschungszentrum fuer WISsensbasierte Systeme (org., KI), http://www.forwiss.tu-muenchen.de, http://www.fmi.uni-passau.de/forwiss/uebersicht.html
 
 @item FOSI
 Format Output Specification Instance (SGML, CALS)
@@ -760,7 +769,7 @@ Format Output Specification Instance (SGML, CALS)
 Free and Open Source Software
 
 @item FOSSFA
-Free Software and Open Source Foundation for Africa (org., Africa)
+Free Software and Open Source Foundation for Africa (org., Africa), http://www.fossfa.net/
 
 @item FOSSIL
 Fido Opus Seadog Standard Interface Layer
@@ -817,7 +826,7 @@ Floating Point Engine
 Field Programmable Function Array
 
 @item FPGA
-Field Programmable Gate Array (RL)
+Field Programmable Gate Array (RL), http://www.mrc.uidaho.edu/fpga/fpga.html
 
 @item FPI
 Flux Changes per Inch (HDD)
@@ -847,7 +856,7 @@ Fast Page Mode [ram] (RAM, DRAM, IC)
 Fast Page Mode DRAM (RAM, DRAM, IC), "FPM-DRAM"
 
 @item FPMPMI
-Flat Panel Monitor Physical Mounting Interface [standard]  [old term] (LCD, VESA, FDMI)
+Flat Panel Monitor Physical Mounting Interface [standard] [old term] (LCD, VESA, FDMI)
 
 @item FPNW
 File and Print service for NetWare (MS, Windows NT, DSMN)
@@ -961,13 +970,13 @@ File System Consistency checK (Unix)
 File System Driver
 
 @item FSF
-Free Software Foundation (org., GNU)
+Free Software Foundation (org., GNU), http://www.gnu.org
 
 @item FSFE
-Free Software Foundation Europe (org., FSF)
+Free Software Foundation Europe (org., FSF), http://www.fsfeurope.org
 
 @item FSG
-Free Standards Group (org.)
+Free Standards Group (org.), http://www.freestandards.org
 
 @item FSH
 File System Hierarchy (Linux, LSB)
@@ -1042,7 +1051,7 @@ Fractional T1 (ISDN, T1, DS-0, DS-1)
 Floptical Technology Association (3M u.a.)
 
 @item FTAM
-File Transfer, Access  and Management (GOSIP, ISO 8571/8572)
+File Transfer, Access and Management (GOSIP, ISO 8571/8572)
 
 @item FTBFS
 Fails To Build From Source (Linux, Debian, slang)
@@ -1075,7 +1084,7 @@ File Transfer Open Systems
 File Transfer OSI Support
 
 @item FTP
-File Transfer Protocol (Internet, RFC 959)
+File Transfer Protocol (Internet, RFC 959), ftp://ftp.rfc-editor.org/in-notes/rfc959.txt
 
 @item FTP
 Foiled Twisted Pair [cable] (UTP, TP)
@@ -1117,7 +1126,7 @@ FernmeldeTechnische Zentralamt / Zulassung (DTAG, ZZF, predecessor)
 Flow Update Acknowledge [message] (LFAP)
 
 @item FUB
-Freie Universitaet Berlin (org.)
+Freie Universitaet Berlin (org.), http://www.inf.fu-berlin.de
 
 @item FUBAB
 Fouled / Fucked Up Beyond All Belief (slang, Usenet, IRC)
@@ -1137,6 +1146,9 @@ Flow Update Notification [message] (LFAP)
 @item FUNI
 Frame User Network Interface
 
+@item FUSE
+Filesystem in USErspace (Linux)
+
 @item FUSSP
 Final Ultimate Solution to the SPAM Problem (SPAM)
 
@@ -1153,7 +1165,7 @@ FirmWare Hub (BIOS, Intel)
 For What It's Worth (slang, Usenet, IRC)
 
 @item FWS
-Folding White Space (RFC 1822)
+Folding White Space (RFC 1822), ftp://ftp.rfc-editor.org/in-notes/rfc1822.txt
 
 @item FWT
 Fast Wavelet Transformation
@@ -1174,7 +1186,7 @@ For Your Information (slang, Usenet, IRC)
 ??? [compression]
 
 @item FZI
-ForschungsZentrum Informatik (org., Uni Karlsruhe, Germany)
+ForschungsZentrum Informatik (org., Uni Karlsruhe, Germany), http://www.fzi.de
 
 @end table
 
