@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2013 Oliver Heidelbach
+@c Copyright (C) 1993/2014 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -52,7 +52,7 @@ Have A Nice Day (slang, Usenet, IRC)
 Highly Available Network File System
 
 @item HAP
-Host Access Protocol (RFC 907/1221)
+Host Access Protocol (RFC 907/1221), ftp://ftp.rfc-editor.org/in-notes/rfc1221.txt, ftp://ftp.rfc-editor.org/in-notes/rfc907.txt
 
 @item HARQ
 Hybrid Automatic Re-transmission reQuest (WIMAX)
@@ -70,13 +70,16 @@ Help Authoring Tool
 High AVailability
 
 @item HAVI
-Home Audio Video Interoperability (org., Grundig, Hitachi, Matsushita, Philips, Sharp, Sony, Thomson, Toshiba)
+Home Audio Video Interoperability (org., Grundig, Hitachi, Matsushita, Philips, Sharp, Sony, Thomson, Toshiba), http://www.havi.org
 
 @item HBA
 Host Bus Adapter (SCSI)
 
+@item HBAO
+Horizon-Based Ambient Occlusion (SSAO)
+
 @item HBCI
-HomeBanking Computer Interface [old term] Internet, banking, Germany, HBCI
+HomeBanking Computer Interface [old term] Internet, banking, Germany, HBCI, http://www.hbci.de
 
 @item HBT
 Hetero Bipolar Transistor (IBM, IC)
@@ -205,7 +208,7 @@ High availability Data Replication (Informix, DB)
 High Dynamic Range
 
 @item HDS
-Hitachi Data Systems (manufacturer)
+Hitachi Data Systems (manufacturer), http://www.hds.com
 
 @item HDSL
 High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL, BIT)
@@ -229,7 +232,7 @@ Half DupleX
 HoehenEinheit [1HE = 19"]
 
 @item HEA
-Hyundai Electronics of America (manufacturer)
+Hyundai Electronics of America (manufacturer), http://www.hea.com/
 
 @item HEC
 Header Error Check
@@ -298,7 +301,7 @@ Hercules Graphics Adapter
 Hercules Graphics Card
 
 @item HHI
-Heinrich Hertz Institut Org., Germany
+Heinrich Hertz Institut Org., Germany, http://www.hhi.de
 
 @item HI
 Hochschulverband Informationswissenschaften (org.)
@@ -343,7 +346,7 @@ Human Interface Graphical GENeration System (Uni Colorado)
 Hierarchical INTegration [benchmark]
 
 @item HIPERLAN
-HIgh PErformance Radio Local Area Network (LAN, ETSI, EN 300 652)
+HIgh PErformance Radio Local Area Network (LAN, ETSI, EN 300 652), http://www.hiperlan.com
 
 @item HIPPI
 HIgh Performance Parallel Interface
@@ -397,7 +400,7 @@ HyperMemory (graphics)
 High Memory Area
 
 @item HMAC
-keyed-Hashing for Message AuthentiCation (cryptography, RFC 2104)
+keyed-Hashing for Message AuthentiCation (cryptography, RFC 2104), ftp://ftp.rfc-editor.org/in-notes/rfc2104.txt
 
 @item HMC
 Hardware Management Console (IBM, Linux)
@@ -421,7 +424,7 @@ HyperMedia Management Schema (MS, Intel, Cisco, WWW)
 High performance Metal Oxide Semiconductor (IC)
 
 @item HMP
-Host Monitoring Protocol (RFC 869)
+Host Monitoring Protocol (RFC 869), ftp://ftp.rfc-editor.org/in-notes/rfc869.txt
 
 @item HMUX
 Hybrid MUltipleXer (FDDI), "H-MUX"
@@ -433,7 +436,7 @@ Host and Network Association [message] (OLSR)
 Heinz Nixdorf Museumsforum (org., Paderborn, Germany)
 
 @item HNI
-Heinz Nixdorf Institut (org., ZIT)
+Heinz Nixdorf Institut (org., ZIT), http://hni.uni-paderborn.de
 
 @item HOD
 Host On Demand (IBM, HOD)
@@ -460,7 +463,7 @@ Half Object Plus Protocol
 High Order Surfaces (3D)
 
 @item HP
-Hewlett Packard (manufacturer)
+Hewlett Packard (manufacturer), http://www.hp.com, http://www.hewlett-packard.de
 
 @item HPA
 High Performance Architecture (HP)
@@ -559,7 +562,7 @@ High Rate (IEEE 802.11)
 Hybrid Ring Control (FDDI)
 
 @item HRFWG
-Home Radio Frequency Working Group (WLAN, HOMERF)
+Home Radio Frequency Working Group (WLAN, HOMERF), http://www.homerf.org
 
 @item HRMS
 Human Resource Management System (Peoplesoft)
@@ -570,6 +573,9 @@ Head Related Transfer Function
 @item HS
 High Speed (MODEM)
 
+@item HSA
+Heterogenous Systems Architecture (AMD)
+
 @item HSA
 High Speed Access
 
@@ -592,7 +598,7 @@ High Speed Circuit Switched Data (GSM, mobile-systems)
 Host Storage Domain (HDS)
 
 @item HSDPA
-High Speed Downlink Packet Access (UMTS, HSUPA)
+High Speed Downlink Packet Access (UMTS, HSUPA, mobile-systems)
 
 @item HSDRAM
 High-speed Synchronous Random Access Memory (RAM, DRAM, IC)
@@ -696,6 +702,9 @@ Hardware Thermal Controller (AMD, IC, CPU)
 @item HTC
 HTML Components (MS, OWA, WWW, HTML)
 
+@item HTCPCP
+Hyper Text Coffee Pot Control Protocol
+
 @item HTDM
 Hybrid Time Division Multiplexing [protocol]
 
@@ -706,7 +715,7 @@ Hyper-g Text Format (Hyper-G)
 Hope This Helps (slang)
 
 @item HTML
-HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942, HTML)
+HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942, HTML), ftp://ftp.rfc-editor.org/in-notes/rfc1942.txt, ftp://ftp.rfc-editor.org/in-notes/rfc1866.txt, http://www.w3.org/MarkUp/
 
 @item HTPC
 Home Theater Personal Computer (PC)
@@ -718,7 +727,7 @@ High Temperature PolySilicon
 Host Transport Service Interface (ICC, CT-API)
 
 @item HTTP
-HyperText Transfer Protocol (WWW, RFC 2068/2616)
+HyperText Transfer Protocol (WWW, RFC 2068/2616), ftp://ftp.rfc-editor.org/in-notes/rfc2068.txt, ftp://ftp.rfc-editor.org/in-notes/rfc2616.txt
 
 @item HTTPD
 HyperText Transfer Protocol DAEMON (WWW, HTTP)
@@ -738,6 +747,9 @@ Head-Up Display (AG)
 @item HUGO
 Holland User Group for OS/2 (org., user group, OS/2, Netherlands)
 
+@item HUMA
+Heterogenous Uniform Memory Access (PS4), "hUMA"
+
 @item HUMAINE
 HUman-MAchine Interaction Network on Emotion [project] (Europe)
 
@@ -756,6 +768,9 @@ High Voltage Differential [technology] (SCSI)
 @item HVD
 Holografic Versatile Disc
 
+@item HVD
+Hosted Virtual Desktop
+
 @item HVM
 Hardware Virtual Machine
 
