@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2013 Oliver Heidelbach
+@c Copyright (C) 1993/2014 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -12,6 +12,9 @@
 @item M2C
 Model To Code (M2M, MDSD)
 
+@item M2M
+Machine To Machine [protocol]
+
 @item M2M
 Model To Model (M2C, MDSD)
 
@@ -55,10 +58,10 @@ Message Address Directory
 Militaerischer AbschirmDienst (mil., org.)
 
 @item MADCAP
-Multicast Address Dynamic Client Allocation Protocol (RFC 2730, Multicast)
+Multicast Address Dynamic Client Allocation Protocol (RFC 2730, Multicast), ftp://ftp.rfc-editor.org/in-notes/rfc2730.txt
 
 @item MADE
-Multimedia Application Development Environment (CWI)
+Multimedia Application Development Environment (CWI), http://www.cwi.nl/cwi/projects/made.html
 
 @item MADK
 Microsoft Activex Development Kit (ActiveX, MS)
@@ -67,13 +70,13 @@ Microsoft Activex Development Kit (ActiveX, MS)
 Multiple APIC Description Table (ACPI, APIC)
 
 @item MAE
-Macintosh Application Environment (Apple, Sun, HPUX)
+Macintosh Application Environment (Apple, Sun, HPUX), http://www.mae.apple.com
 
 @item MAE
 Metropolitan Area Exchange (Internet)
 
 @item MAEC
-Malware Attribute Enumeration and Characterization
+Malware Attribute Enumeration and Characterization, http://maec.mitre.org/
 
 @item MAINSAIL
 MAchine INdependent SAIL (SAIL)
@@ -121,13 +124,13 @@ Multimedia APplications in Education Conference, "MApEC"
 Messaging Application Program Interface (MS, WOSA, API)
 
 @item MAPOS
-Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171)
+Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171), ftp://ftp.rfc-editor.org/in-notes/rfc2171.txt
 
 @item MAPP
 Microsoft Active Protections Program (MS)
 
 @item MAPS
-Microsoft Active Protection System (MS)
+Microsoft Active Protection System (MS, MSE)
 
 @item MAPS
 Multiple Airflow Pass-through Structure (Scythe), M.A.P.S.
@@ -154,7 +157,7 @@ Multi Agent Systems (AI)
 Mittelstands-Anwendungs-System 90 (IBM)
 
 @item MASC
-Multicast Address-Set Claim [protocol] (RFC 2909, Multicast)
+Multicast Address-Set Claim [protocol] (RFC 2909, Multicast), ftp://ftp.rfc-editor.org/in-notes/rfc2909.txt
 
 @item MASE
 Message Administration Service Element
@@ -175,7 +178,7 @@ Medium Attachment Unit (IEEE 802.3, Transceiver)
 Multistation Access Unit (Token Ring, Hub)
 
 @item MAUS
-Muensters Apple User Service (BBS, network), "M.A.U.S."
+Muensters Apple User Service (BBS, network), "M.A.U.S.", http://www.maus.de
 
 @item MAW
 Microsoft At Work
@@ -220,7 +223,7 @@ Mega Binary digIT (BIT), "MBit"
 Media Bandwidth Management (DSL, Zyxel)
 
 @item MBOA
-MultiBand OFDM Alliance (org., OFDM)
+MultiBand OFDM Alliance (org., OFDM), http://www.multibandofdm.org
 
 @item MBPS
 MegaBits Per Second (BIT)
@@ -289,10 +292,10 @@ Media Center Edition (MS, Windows, XP, OEM)
 Military Communications-Electronics Board (org., mil., USA)
 
 @item MCERT
-Mittelstand Computer Emergency Response Team Germany
+Mittelstand Computer Emergency Response Team Germany, http://www.mcert.de
 
 @item MCF
-Meta Content Framework / Format (Apple, WWW)
+Meta Content Framework / Format (Apple, WWW), http://mcf.research.apple.com
 
 @item MCF
 MOM Connector Framework (MS, MOM)
@@ -310,10 +313,10 @@ Measurement Layer Interface (UMA)
 Media Control Interface
 
 @item MCI
-Microwave Communications Incorporated
+Microwave Communications Incorporated, http://www.mci.com
 
 @item MCL
-Media Communication Lab (org., Uni Boston, USA)
+Media Communication Lab (org., Uni Boston, USA), http://spiderman.bu.edu
 
 @item MCM
 Multi Carrier Modulation
@@ -325,7 +328,7 @@ MultiChip Module (CPU)
 Metropolitan Campus Network
 
 @item MCNE
-Master Certified Netware Engineer (Novell, Netware)
+Master Certified Netware Engineer (Novell, Netware), http://www.novell.com/education/mcne/
 
 @item MCNS
 Multimedia Cable Network System (org.)
@@ -424,13 +427,13 @@ Management Domain
 Mini Disk (Sony)
 
 @item MD2
-Message Digest [algorithm] 2 (RFC 1115/1319)
+Message Digest [algorithm] 2 (RFC 1115/1319), ftp://ftp.rfc-editor.org/in-notes/rfc1319.txt, ftp://ftp.rfc-editor.org/in-notes/rfc1115.txt
 
 @item MD4
-Message Digest [algorithm] 4 (RFC 1320)
+Message Digest [algorithm] 4 (RFC 1320), ftp://ftp.rfc-editor.org/in-notes/rfc1320.txt
 
 @item MD5
-Message Digest [algorithm] 5 (RFC 1321)
+Message Digest [algorithm] 5 (RFC 1321), ftp://ftp.rfc-editor.org/in-notes/rfc1321.txt
 
 @item MDA
 Mail Delivery Agent
@@ -481,7 +484,7 @@ Menu DEfinition Functions (Apple, CDEF)
 Medium Dependent Interface (ethernet)
 
 @item MDI
-Mobile Data Initiative (org., GSM, mobile-systems)
+Mobile Data Initiative (org., GSM, mobile-systems), http://www.gsmdata.com
 
 @item MDI
 Multiple Document Interface (MS, Windows)
@@ -595,7 +598,7 @@ Menue-EntwicklungsSystem (Sinix, SNI)
 Minimum European Set (UTF, ISO 10646)
 
 @item MESA
-MetaEmailSearchAgent (WWW, Internet)
+MetaEmailSearchAgent (WWW, Internet), http://mesa.rrzn.uni-hannover.de/
 
 @item MESCH
 Multi-WAIS Engine for Searching Commercial Hosts (WAIS, WWW)
@@ -634,10 +637,10 @@ Macro Expansion Template Attribute Language (TAL, ZPT, ZOPE)
 Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)
 
 @item MEU
-Multiformat  Engine Unit (LCD, Sony)
+Multiformat Engine Unit (LCD, Sony)
 
 @item MEWDE
-My EMACS Web Development Environment (EMACS, WWW)
+My EMACS Web Development Environment (EMACS, WWW), http://mewde.blogspot.com
 
 @item MEZ
 MittelEuropaeische [sommer] Zeit [+0200] (TZ)
@@ -646,7 +649,7 @@ MittelEuropaeische [sommer] Zeit [+0200] (TZ)
 Multi Frequency
 
 @item MFAST
-Mwave Folded Array Signal Transform [DSP] (IBM, DSP)
+Mwave Folded Array Signal Transform [DSP] (IBM, DSP), http://watson.mbb.sfu.ca
 
 @item MFC
 Memory Flow Controller (SPE, Cell, IBM)
@@ -718,7 +721,7 @@ Matrox Graphics Adapter (Matrox)
 Monochrome Graphics Adapter
 
 @item MGCP
-Media Gateway Control Protocol (VoIP, RFC 2705)
+Media Gateway Control Protocol (VoIP, RFC 2705), ftp://ftp.rfc-editor.org/in-notes/rfc2705.txt
 
 @item MGI
 Multi-Function Interpreter
@@ -745,7 +748,7 @@ Mobile High-definition Link
 [columbia] Mobile Host Protocol
 
 @item MHP
-Multimedia Home Platform (ETSI)
+Multimedia Home Platform (ETSI), http://www.mhp-forum.de
 
 @item MHPCC
 Maui High Performance Computing Center (org., USA)
@@ -757,7 +760,7 @@ Message Handling System (GOSIP, X.400, Novell, SPX, IPX)
 Messaging HyperText Markup Language (HTML)
 
 @item MHTML
-MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RFC 2110)
+MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RFC 2110), ftp://ftp.rfc-editor.org/in-notes/rfc2110.txt
 
 @item MI
 Management Interface
@@ -796,7 +799,7 @@ MODEM ISDN Channel Integration (Telebit, MODEM, ISDN)
 Modular Integrated Communications Environment
 
 @item MICO
-MICO Is CORBA (ORB, CORBA, Uni Frankfurt)
+MICO Is CORBA (ORB, CORBA, Uni Frankfurt), http://diamant-atm.vsb.cs.uni-frankfurt.de/~mico
 
 @item MID
 Message IDentifier (ATM)
@@ -808,7 +811,7 @@ Mobile Information Device
 Multiple Interface Declaration (OLSR)
 
 @item MIDI
-Musical Instruments Digital Interface (MIDI)
+Musical Instruments Digital Interface (MIDI), http://www.midi.org
 
 @item MIDL
 Microsoft Interface Definition Language (NT)
@@ -853,14 +856,14 @@ Military STandarD (mil., USA), "MIL-STD"
 Multiple Instruction [stream], Multiple Data [stream] (CPU)
 
 @item MIME
-Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)
-
-@item MIMO
-Multiple Input, Multiple Output (Agere-Systems, WLAN, Bell)
+Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF), ftp://ftp.rfc-editor.org/in-notes/rfc2045.txt, ftp://ftp.rfc-editor.org/in-notes/rfc2046.txt
 
 @item MIMO
 Multiple Input, Multiple Output (WLAN)
 
+@item MIMO
+Multiple Input, Multiple Output (Agere-Systems, WLAN, Bell)
+
 @item MIMOLA
 Machine Independent MicrOprogramming LAnguage (HDL)
 
@@ -931,19 +934,19 @@ Multiple Input, Single Output (WLAN)
 Motor Industry Software Reliability Association (UK)
 
 @item MISS
-Mecklenburg Internet Service System (ISP)
+Mecklenburg Internet Service System (ISP), http://www.miss.net
 
 @item MISSI
 Multilevel Information System Security Initiative (org.)
 
 @item MISX
-Metered Services Information eXchange (Internet)
+Metered Services Information eXchange (Internet), http://www.msix.org
 
 @item MIT
 Management Information Tree
 
 @item MIT
-Massachusetts Institute of Technology (org., USA)
+Massachusetts Institute of Technology (org., USA), http://www.lcs.mit.edu, http://www.ai.mit.edu
 
 @item MIT
 Mobile Internet Toolkit (MS, .NET)
@@ -952,7 +955,7 @@ Mobile Internet Toolkit (MS, .NET)
 Modular Jack
 
 @item MKS
-Mortice Kern Systems (manufacturer)
+Mortice Kern Systems (manufacturer), http://www.mks.com
 
 @item MKT
 Multifunktionelles KartenTerminal (CT, ICC)
@@ -979,7 +982,7 @@ Micro Lens Array
 Multi Level Cell (IC, PCMCIA, Flash, Intel, SLC)
 
 @item MLD
-Multicast Listener Discovery [protocol] (IPV6, Multicast, RFC 2710)
+Multicast Listener Discovery [protocol] (IPV6, Multicast, RFC 2710), ftp://ftp.rfc-editor.org/in-notes/rfc2710.txt
 
 @item MLE
 MultiLine Entry field (IBM, OS/2)
@@ -991,7 +994,7 @@ Measurement Layer Interface (UMA)
 Multiple Link Interface (ODI)
 
 @item MLIA
-[symposium on] Machine Learning in Information Access (AAAI, AI, conference)
+[symposium on] Machine Learning in Information Access (AAAI, AI, conference), http://www.parc.xerox.com/istl/projects/mlia
 
 @item MLID
 Multiple Link Interface Driver (ODI, LAN)
@@ -1033,7 +1036,7 @@ Military Message (mil.)
 Mobile Management (RR, CM, GSM, mobile-systems)
 
 @item MMA
-Microcomputer Managers Association (org., USA)
+Microcomputer Managers Association (org., USA), http://www.midi.org
 
 @item MMA
 MIDI Manufacturer Association (org., IMA)
@@ -1063,7 +1066,7 @@ MultiMedia Compact Disk (Sony, Philips, CD)
 MultiMedia Compact Disk - Erasable (Sony, Philips, CD), "MMCD-E"
 
 @item MMCF
-MultiMedia Communications Forum (org.)
+MultiMedia Communications Forum (org.), http://www.mmcf.org
 
 @item MMDO
 Magnetic Modulation Direct Overwrite
@@ -1117,7 +1120,7 @@ Modified Modified Read (Fax)
 Mobile Multi-hop Relay Study Group (IEEE), "MMR SG"
 
 @item MMS
-Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506)
+Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506), http://icawww.epfl.ch/MMS/
 
 @item MMS
 Maximum Message Size
@@ -1242,6 +1245,9 @@ Meta Object Protocol (CLOS)
 @item MOP
 Multiple Original Prints
 
+@item MOPRIA
+MObile PRinting Alliance (org., Canon, HP, Samsung, Xerox), http://www.mopria.org/
+
 @item MOPS
 Million Operations Per Second
 
@@ -1267,13 +1273,13 @@ Major Open Systems Environment Standards
 Metal Oxide Semiconductor Field Effect Transistor (IC, FET)
 
 @item MOSIX
-Multicomputer Operating System for UnIX (Unix, Cluster, MOSIX)
+Multicomputer Operating System for UnIX (Unix, Cluster, MOSIX), http://www.mosix.org
 
 @item MOSP
 Microsoft Online Services Partnership (MSN)
 
 @item MOSPF
-Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584)
+Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584), ftp://ftp.rfc-editor.org/in-notes/rfc1584.txt
 
 @item MOSRO
 MObiles-Sicherheits-ROboter-System
@@ -1282,7 +1288,7 @@ MObiles-Sicherheits-ROboter-System
 Media Orientated Systems Transport
 
 @item MOST
-Mobile Open Systems Technologies (UK, Uni Lancaster)
+Mobile Open Systems Technologies (UK, Uni Lancaster), http://www.lancs.ac.uk/computing/research/mpq/projects.html#MOST
 
 @item MOT
 Means of Test
@@ -1309,7 +1315,7 @@ Microsoft Overlay Virtual Environment (MS)
 Magneto-Optical Write Once Read Many, "MO-WORM" 
 
 @item MP
-[PPP] Multilink Protocol (MPPP, RFC 1990)
+[PPP] Multilink Protocol (MPPP, RFC 1990), ftp://ftp.rfc-editor.org/in-notes/rfc1990.txt
 
 @item MP
 Management Pack (MS, MOM)
@@ -1324,7 +1330,7 @@ Multi Processor
 MultiProtocol
 
 @item MP3
-MPEG audio layer 3 (MPEG, audio, IIS, ISO)
+MPEG audio layer 3 (MPEG, audio, IIS, ISO), http://www.mp3.com
 
 @item MPC
 Modular Port Concentrator
@@ -1354,7 +1360,7 @@ Multi-Programming Executive (OS, HP, HP 3000)
 Motion Picture Expert Group [old term] (MPEG)
 
 @item MPEG
-Moving Picture Expert Group (org., ISO 11172-1, JTC1)
+Moving Picture Expert Group (org., ISO 11172-1, JTC1), http://www.cselt.it/mpeg
 
 @item MPEGTS
 Moving Picture Expert Group - Transport Stream (MPEG, TS), MPEG-TS
@@ -1365,6 +1371,9 @@ Multiple Programming Executive/V (HP), "MPE/V"
 @item MPEXL
 Multiple Programming Executive/XL (HP), "MPE/XL"
 
+@item MPF1
+MikroProFessor 1, "MPF 1"
+
 @item MPI
 Message Passing Interface (SMP, Cluster)
 
@@ -1378,7 +1387,7 @@ Message Passing Interface Forum (manufacturer)
 Mozilla Public License (Netscape)
 
 @item MPLS
-Multi-Protocol Label Switching (RFC 3031)
+Multi-Protocol Label Switching (RFC 3031), ftp://ftp.rfc-editor.org/in-notes/rfc3031.txt
 
 @item MPM
 Metra Potential Method
@@ -1411,22 +1420,22 @@ Multiple Purpose Operator Workstation
 Massive Parallel Processor / Processing (MPP)
 
 @item MPP
-Message Posting Protocol (RFC 1204)
+Message Posting Protocol (RFC 1204), ftp://ftp.rfc-editor.org/in-notes/rfc1204.txt
 
 @item MPP
 Message Processing Program
 
 @item MPPC
-Microsoft Point-to-Point Compression (MS, RFC 2118)
+Microsoft Point-to-Point Compression (MS, RFC 2118), ftp://ftp.rfc-editor.org/in-notes/rfc2118.txt
 
 @item MPPD
 Multi Purpose Peripheral Device
 
 @item MPPE
-Microsoft Point to Point Encryption (MS, cryptography, RFC 3078)
+Microsoft Point to Point Encryption (MS, cryptography, RFC 3078), ftp://ftp.rfc-editor.org/in-notes/rfc3078.txt
 
 @item MPPP
-Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)
+Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend), ftp://ftp.rfc-editor.org/in-notes/rfc1990.txt
 
 @item MPR
 Maet- och Provningsradet [National Board for Measurement and Testing] (org., Sweden, SWEDAC)
@@ -1489,10 +1498,10 @@ MIDI Processing Unit 401 (Roland, MIDI), "MPU 401"
 Macintosh Programmers Workshop (Apple)
 
 @item MPX
-MultiProgramming eXecutive (OS)
+MultiProgramming eXecutive (IBM, OS, IBM 1800)
 
 @item MPX
-MultiProgramming eXecutive (IBM, OS, IBM 1800)
+MultiProgramming eXecutive (OS)
 
 @item MQI
 Message Queueing Interface (IBM)
@@ -1549,7 +1558,7 @@ Macintosh Runtime for Java Software Developer Kit (Apple, Java), "MRJ SDK"
 Multi Resolution Meshes (Intel, 3D)
 
 @item MRML
-Multimedia Retrieval Markup Language (Multimedia, Internet, XML)
+Multimedia Retrieval Markup Language (Multimedia, Internet, XML), http://www.mrml.net
 
 @item MRNET
 Minnesota Regional NETwork (network, USA)
@@ -1606,7 +1615,7 @@ Message Store
 Meta Signaling (ATM, ???)
 
 @item MS
-MicroSoft (manufacturer, MS)
+MicroSoft (manufacturer, MS), http://www.microsoft.com, http://www.microsoft.de
 
 @item MS
 Mobile Station (GSM, mobile-systems)
@@ -1684,7 +1693,7 @@ MicroSoft Developer Network Academic Alliance (MS)
 MicroSoft Disk Operating System (MS, OS, PC)
 
 @item MSDP
-Multicast Source Discovery Protocol (Internet, PIM-SM, Multicast, RFC 3618)
+Multicast Source Discovery Protocol (Internet, PIM-SM, Multicast, RFC 3618), ftp://ftp.rfc-editor.org/in-notes/rfc3618.txt
 
 @item MSE
 Mean Squared Error
@@ -1720,7 +1729,7 @@ Medium Scale Integration
 MicroSoft Installer (MS, WIndows)
 
 @item MSI
-Micro-Star International (manufacturer, Taiwan)
+Micro-Star International (manufacturer, Taiwan), http://www.msi.com.tw
 
 @item MSIE
 MicroSoft Internet Explorer (MS, WWW, MSIE)
@@ -1732,7 +1741,7 @@ MicroSoft Intermediate Language (MS, .NET, CLI)
 Mobile Station ISDN Number (PLMN, GSM, mobile-systems), "MS-ISDN"
 
 @item MSIX
-Metered Services Information eXchange [protocol] (Internet, ISP)
+Metered Services Information eXchange [protocol] (Internet, ISP), http://www.msix.org
 
 @item MSJVM
 MicroSoft Java Virtual Machine (MS, Java)
@@ -1777,7 +1786,7 @@ Media Signal Processor (Samsung, MMX, ARM)
 Message Security Protocol
 
 @item MSP
-Message Send Protocol (RFC 1159)
+Message Send Protocol (RFC 1159), ftp://ftp.rfc-editor.org/in-notes/rfc1159.txt
 
 @item MSP
 Multitasking System Program (OS, Hemenway)
@@ -1804,7 +1813,7 @@ Mobile Support Router (MHP)
 Model Specific Register (Intel, Pentium, IC)
 
 @item MSRL
-MicroSoft Reciprocal  License (MS, Ms-PL), "Ms-RL"
+MicroSoft Reciprocal License (MS, Ms-PL), "Ms-RL"
 
 @item MSRN
 Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM, mobile-systems)
@@ -1915,7 +1924,7 @@ Modulation Transfer Function
 Memory Translator Hub (Intel)
 
 @item MTI
-MIPS Technologies Inc. (manufacturer, SGI)
+MIPS Technologies Inc. (manufacturer, SGI), http://www.mips.com
 
 @item MTJ
 Magnetic Tunnel Junction (MRAM)
@@ -2014,7 +2023,7 @@ Massachusetts general hospital Multi-Programming System
 Multi-User Multi-Programming System ??? (OS, DEC)
 
 @item MUPAD
-Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD"
+Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD", http://math-www.uni.paderborn.de/~cube
 
 @item MUSH
 Multi-User Shared Hallucination (MUD)
@@ -2062,7 +2071,7 @@ Multi-Vendor Interacting Forum (org., IN)
 Most Valuable Professional [bonus program] (MS)
 
 @item MVRCA
-Magnalink Variable Resource Compression Algorithm (PPP, RFC 1975)
+Magnalink Variable Resource Compression Algorithm (PPP, RFC 1975), ftp://ftp.rfc-editor.org/in-notes/rfc1975.txt
 
 @item MVS
 Multiple Virtual Storage (IBM, OS, OS/MVS)
@@ -2125,7 +2134,7 @@ MobilitY DisplayPort, "MyDP"
 Mark Zbikowski (MS-DOS, MCB)
 
 @item MZAP
-Multicast-scope Zone Announcement Protocol (RFC 2776, Multicast)
+Multicast-scope Zone Announcement Protocol (RFC 2776, Multicast), ftp://ftp.rfc-editor.org/in-notes/rfc2776.txt
 
 @end table
 
