@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2013 Oliver Heidelbach
+@c Copyright (C) 1993/2014 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -49,10 +49,10 @@ Rapid Access Disk
 Rapid Application Development [toolkit] (Delphi, Borland)
 
 @item RAD
-Research And Development [data communications] (manufacturer)
+Research And Development [data communications] (manufacturer), http://www.rad.co.il
 
 @item RADIUS
-Remote Authentication Dial-In User Service (RFC 2865)
+Remote Authentication Dial-In User Service (RFC 2865), ftp://ftp.rfc-editor.org/in-notes/rfc2865.txt
 
 @item RADSL
 Rate Adaptive Digital Subscriber Line (ADSL)
@@ -105,11 +105,14 @@ Reliability, Availability, Manageability, Performance and Scalability (DB)
 @item RAMS
 Record Archival Management System
 
+@item RAN
+Radio Access Network
+
 @item RAND
 Rural Area Network Design
 
 @item RAP
-[internet] Route Access Protocol (RFC 1476, Internet)
+[internet] Route Access Protocol (RFC 1476, Internet), ftp://ftp.rfc-editor.org/in-notes/rfc1476.txt
 
 @item RAP
 Remote Access Point
@@ -127,7 +130,7 @@ Real Application on Parallel Systems
 Reseaux Associes pour la Recherche Europeenne (org.)
 
 @item RARP
-Reverse Address Resolution Protocol (Internet, RFC 903)
+Reverse Address Resolution Protocol (Internet, RFC 903), ftp://ftp.rfc-editor.org/in-notes/rfc903.txt
 
 @item RAS
 Reliability, Availability and Serviceability (IBM)
@@ -148,7 +151,7 @@ Remote Access Tool
 Remote Access Trojan
 
 @item RATP
-Reliable Asynchronous Transfer Protocol (RFC 916)
+Reliable Asynchronous Transfer Protocol (RFC 916), ftp://ftp.rfc-editor.org/in-notes/rfc916.txt
 
 @item RATS
 Radio-Amateur Telecommunications Society (org., USA)
@@ -211,7 +214,7 @@ Rivest Cipher / Ron's Code 2 (cryptography)
 Rivest Cipher / Ron's Code 4 (cryptography)
 
 @item RC5
-Rivest Cipher 5 (RFC 2040, cryptography)
+Rivest Cipher 5 (RFC 2040, cryptography), ftp://ftp.rfc-editor.org/in-notes/rfc2040.txt
 
 @item RCAS
 Reserve Component Automation System
@@ -322,7 +325,7 @@ Random Digital Dial
 Replaceable Database Driver (Clipper, CA-VO, DB)
 
 @item RDDL
-Resource Directory Description Language (XHTML, XML)
+Resource Directory Description Language (XHTML, XML), http://www.rddl.org
 
 @item RDE
 Received Data Enable
@@ -406,7 +409,7 @@ Request Data with Reply (Feldbus)
 Rambus Dynamic Random Access Memory (RAM, IC, Rambus)
 
 @item RDRN
-Rapidly Deployable Radio Networks (USA, Uni Kansas)
+Rapidly Deployable Radio Networks (USA, Uni Kansas), http://www.tisl.ukans.edu/rdrn
 
 @item RDS
 Radio Digital System
@@ -484,7 +487,7 @@ Remote Entry Services
 REpresentational State Transfer (URL, AWS)
 
 @item RESTENA
-RESeau Teleinformatique de l'Education NAtionale et de la recherce (network, Luxembourg)
+RESeau Teleinformatique de l'Education NAtionale et de la recherce (network, Luxembourg), http://www.restena.lu
 
 @item RET
 Report Engine Technology (CA, DB)
@@ -697,16 +700,16 @@ Remote Imaging Protocol (BBS)
 Return Instruction Pointer (CPU, RAM)
 
 @item RIP
-Routing Information Protocol (BSD, IGP, RFC 1721, IP)
+Routing Information Protocol (BSD, IGP, RFC 1721, IP), ftp://ftp.rfc-editor.org/in-notes/rfc1721.txt
 
 @item RIPE
-Reseaux IP Europeenne (Europenet)
+Reseaux IP Europeenne (Europenet), http://www.ripe.net
 
 @item RIPL
 Remote Initial Program Load (IBM)
 
 @item RIPNG
-Routing Information Protocol Next Generation (RIP, IPV6, RFC 2080), "RIPng"
+Routing Information Protocol Next Generation (RIP, IPV6, RFC 2080), "RIPng", ftp://ftp.rfc-editor.org/in-notes/rfc2080.txt
 
 @item RIPS
 Raster Image Processing Systems corporation (manufacturer)
@@ -742,7 +745,7 @@ Regional Information Technology and Software Engineering Center
 Registered Jack 45 (cable)
 
 @item RJE
-Remote Job Entry (IBM, Internet, RFC 407)
+Remote Job Entry (IBM, Internet, RFC 407), ftp://ftp.rfc-editor.org/in-notes/rfc407.txt
 
 @item RJEF
 Remote Job Entry Function
@@ -787,7 +790,7 @@ Remote LAN Nodes (LAN)
 Radio Link Protocol (GSM, mobile-systems)
 
 @item RLP
-Resource Location Protocol (Internet, RFC 887)
+Resource Location Protocol (Internet, RFC 887), ftp://ftp.rfc-editor.org/in-notes/rfc887.txt
 
 @item RLPR
 Remote Line Printing Request (LPR, printing)
@@ -877,7 +880,7 @@ Rights Management Services (MS, Windows, NGSCB)
 Raw Magnetic Tape (Unix)
 
 @item RMT
-Reliable Multicast Transport (IETF, WG, Multicast)
+Reliable Multicast Transport (IETF, WG, Multicast), http://www.ietf.org/html.charters/rmt-charter.html
 
 @item RMT
 REXXware Migration Tool (Simware, REXX)
@@ -892,7 +895,7 @@ Reverse Mail eXchange (DNS, SPAM)
 Remote Network Access
 
 @item RNC
-Radio Network Controller (mobile-systems, UMTS)
+Radio Network Controller (mobile-systems, UMTS, RAN)
 
 @item RND
 RAD Network Devices (RAD, manufacturer)
@@ -952,7 +955,7 @@ Read-Only Domain Controller (MS, AD)
 Roar Out From Laughing (slang, Usenet, IRC)
 
 @item ROHC
-RObust Header Compression (RFC 3095/3759, RTP, UDP, ESP)
+RObust Header Compression (RFC 3095/3759, RTP, UDP, ESP), ftp://ftp.rfc-editor.org/in-notes/rfc3095.txt, ftp://ftp.rfc-editor.org/in-notes/rfc3759.txt
 
 @item ROHS
 Restriction Of the use of certain Hazardous Substances in electrical and electronical equipment (Europe), "RoHS"
@@ -1021,7 +1024,7 @@ Remote Phrase Authentication
 Region Playback Control (DVD)
 
 @item RPC
-Remote Procedure Call (Sun, Xerox, OSF, ECMA, RFC 1831)
+Remote Procedure Call (Sun, Xerox, OSF, ECMA, RFC 1831), ftp://ftp.rfc-editor.org/in-notes/rfc1831.txt
 
 @item RPC2
 Region code Playback Control phase 2 (DVD), "RPC-2"
@@ -1111,10 +1114,10 @@ Radial Run Out (DVD)
 Red Ring Of Death (MS, Xbox)
 
 @item RRP
-Registry Registrar Protocol (VeriSign, RFC 2832/3632)
+Registry Registrar Protocol (VeriSign, RFC 2832/3632), ftp://ftp.rfc-editor.org/in-notes/rfc2832.txt, ftp://ftp.rfc-editor.org/in-notes/rfc3632.txt
 
 @item RRZE
-Regionales RechenZentrum Erlangen (org.)
+Regionales RechenZentrum Erlangen (org.), http://www.rrze.uni-erlangen.de
 
 @item RRZN
 Regionales RechenZentrum fuer Niedersachsen (org.)
@@ -1258,7 +1261,7 @@ Remote Software Update (IBDM, OS/2, ...)
 Remote Switching Unit
 
 @item RSVP
-Resource reSerVation Protocol (IP, RFC 2205)
+Resource reSerVation Protocol (IP, RFC 2205), ftp://ftp.rfc-editor.org/in-notes/rfc2205.txt
 
 @item RSX
 Realistic Sound eXperience (Intel, audio)
@@ -1414,7 +1417,7 @@ Real Time Operating System /360 (IBM, OS, S/360), "RTOS/360"
 Real Time Operating System - Universitaet Hannover (OS), "RTOS-UH"
 
 @item RTP
-Real Time Protocol (Internet, RFC 1889/1890, RTCP)
+Real Time Protocol (Internet, RFC 1889/1890, RTCP), ftp://ftp.rfc-editor.org/in-notes/rfc1889.txt, ftp://ftp.rfc-editor.org/in-notes/rfc1890.txt
 
 @item RTS
 Real Time Strategy [game] (TBS)
@@ -1438,7 +1441,7 @@ Reliable Transfer Service Element (OSI)
 RealTime System Manager
 
 @item RTSP
-Real Time Streaming Protocol (TV, WWW, UDP, TCP/IP, RDP, Multicast, VoIP, RFC 2326)
+Real Time Streaming Protocol (TV, WWW, UDP, TCP/IP, RDP, Multicast, VoIP, RFC 2326), ftp://ftp.rfc-editor.org/in-notes/rfc2326.txt
 
 @item RTT
 Resonant Tunneling Transistor
@@ -1488,6 +1491,9 @@ Remote User Access Centers
 @item RUI
 Reality User Interface
 
+@item RUM
+Real User Monitoring (WWW)
+
 @item RUOW
 Remote Unit Of Work (DRDA, IBM), "RUoW"
 
@@ -1531,7 +1537,7 @@ RechenZentrum
 Return-to-Zero [recording]
 
 @item RZG
-RechenZentrum Garching
+RechenZentrum Garching, http://www.rzg.mpg.de/rzg.html
 
 @item RZM
 RootZone Maintainer (DNS)
